Ejegg has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/320267

Change subject: WIP rename 'zip' to 'postal'
......................................................................

WIP rename 'zip' to 'postal'

This will need to be deployed during some downtime. Also, make sure
the outgoing queue messages are intelligible.

TODO: clean up the .json files. In languages with a US-specific
'zip code' in zip and a generic 'postal code' in postal, move the
zip value to -postal-us.

Change-Id: I7a60dccae692631a32381a69eef2dd1c6ba9e32e
---
M adyen_gateway/BlankAddressFields.php
M adyen_gateway/config/country_fields.yaml
M adyen_gateway/config/var_map.yaml
M astropay_gateway/config/var_map.yaml
M extension.json
M extras/custom_filters/filters/minfraud/minfraud.body.php
M gateway_common/DataValidator.php
M gateway_common/DonationData.php
M gateway_common/DonationQueue.php
M gateway_common/StreetAddress.php
M gateway_common/donation.api.php
M gateway_common/gateway.adapter.php
M gateway_forms/Mustache.php
M gateway_forms/mustache/personal_info.html.mustache
M globalcollect_gateway/config/data_constraints.yaml
M globalcollect_gateway/config/var_map.yaml
M modules/js/ext.donationInterface.forms.js
M tests/phpunit/Adapter/Adyen/AdyenTest.php
M tests/phpunit/Adapter/GatewayAdapterTest.php
M tests/phpunit/Adapter/GlobalCollect/GlobalCollectFormLoadTest.php
M tests/phpunit/Adapter/GlobalCollect/GlobalCollectTest.php
M tests/phpunit/DonationDataTest.php
M tests/phpunit/DonationInterfaceTestCase.php
M tests/phpunit/DonationQueueTest.php
M tests/phpunit/GatewayPageTest.php
M tests/phpunit/LoggingTest.php
26 files changed, 67 insertions(+), 68 deletions(-)


  git pull 
ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/DonationInterface 
refs/changes/67/320267/1

diff --git a/adyen_gateway/BlankAddressFields.php 
b/adyen_gateway/BlankAddressFields.php
index 5ac411e..786bd44 100644
--- a/adyen_gateway/BlankAddressFields.php
+++ b/adyen_gateway/BlankAddressFields.php
@@ -12,7 +12,7 @@
                'state',
                'street',
                'street_supplemental',
-               'zip',
+               'postal',
                );
 
        public function stage( GatewayType $adapter, $normalized, &$stagedData 
) {
@@ -41,4 +41,4 @@
                }
        }
 
-}
\ No newline at end of file
+}
diff --git a/adyen_gateway/config/country_fields.yaml 
b/adyen_gateway/config/country_fields.yaml
index 4f89f1b..f923d2f 100644
--- a/adyen_gateway/config/country_fields.yaml
+++ b/adyen_gateway/config/country_fields.yaml
@@ -6,4 +6,4 @@
     address: true
 US:
     street: true
-    zip: true
+    postal: true
diff --git a/adyen_gateway/config/var_map.yaml 
b/adyen_gateway/config/var_map.yaml
index 5321ada..f183d99 100644
--- a/adyen_gateway/config/var_map.yaml
+++ b/adyen_gateway/config/var_map.yaml
@@ -1,7 +1,7 @@
 allowedMethods: allowed_methods
 billingAddress.city: city
 billingAddress.country: country
-billingAddress.postalCode: zip
+billingAddress.postalCode: postal
 billingAddress.stateOrProvince: state
 billingAddress.street: street
 billingAddress.houseNumberOrName: street_supplemental
diff --git a/astropay_gateway/config/var_map.yaml 
b/astropay_gateway/config/var_map.yaml
index ffecdc3..e7448ab 100644
--- a/astropay_gateway/config/var_map.yaml
+++ b/astropay_gateway/config/var_map.yaml
@@ -13,7 +13,7 @@
 # We've been told bdate is non-mandatory, despite the docs
 x_bdate: birth_date
 x_address: street
-x_zip: zip
+x_zip: postal
 x_city: city
 x_state: state
 x_document: gateway_txn_id
diff --git a/extension.json b/extension.json
index 9e822b5..48ebf6a 100644
--- a/extension.json
+++ b/extension.json
@@ -252,7 +252,6 @@
                                "donate_interface-donor-street",
                                "donate_interface-donor-city",
                                "donate_interface-donor-state",
-                               "donate_interface-donor-zip",
                                "donate_interface-donor-postal",
                                "donate_interface-donor-country",
                                "donate_interface-donor-email",
diff --git a/extras/custom_filters/filters/minfraud/minfraud.body.php 
b/extras/custom_filters/filters/minfraud/minfraud.body.php
index 009f96d..8f0dac9 100644
--- a/extras/custom_filters/filters/minfraud/minfraud.body.php
+++ b/extras/custom_filters/filters/minfraud/minfraud.body.php
@@ -155,7 +155,7 @@
                $map = array(
                        "city" => "city",
                        "region" => "state",
-                       "postal" => "zip",
+                       "postal" => "postal",
                        "country" => "country",
                        "domain" => "email",
                        "emailMD5" => "email",
diff --git a/gateway_common/DataValidator.php b/gateway_common/DataValidator.php
index 51c3f79..0a96a12 100644
--- a/gateway_common/DataValidator.php
+++ b/gateway_common/DataValidator.php
@@ -38,7 +38,7 @@
                        case 'country':
                        case 'street':
                        case 'state':
-                       case 'zip':
+                       case 'postal':
                                $error_token = $field;
                                break;
                        default:
@@ -71,7 +71,7 @@
                        'country' => '',
                        'street' => '',
                        'state' => '',
-                       'zip' => '',
+                       'postal' => '',
                        'email' => '',
                );
        }
diff --git a/gateway_common/DonationData.php b/gateway_common/DonationData.php
index b11bd67..7147bd2 100644
--- a/gateway_common/DonationData.php
+++ b/gateway_common/DonationData.php
@@ -49,7 +49,7 @@
                'street_supplemental',
                'city',
                'state',
-               'zip',
+               'postal',
                'country',
                'card_num',
                'card_type',
@@ -925,7 +925,7 @@
                        'city',
                        'state',
                        'country',
-                       'zip',
+                       'postal',
                        'gateway',
                        'gateway_account',
                        'gateway_txn_id',
diff --git a/gateway_common/DonationQueue.php b/gateway_common/DonationQueue.php
index 91d7b2f..b82528d 100644
--- a/gateway_common/DonationQueue.php
+++ b/gateway_common/DonationQueue.php
@@ -273,7 +273,7 @@
                        'subscr_id' => 'subscr_id',
                        'utm_campaign' => 'utm_campaign',
                        'utm_medium' => 'utm_medium',
-                       'postal_code' => 'zip',
+                       'postal' => 'postal',
                );
                foreach ( $optional_keys as $mkey => $tkey ) {
                        if ( isset( $transaction[$tkey] ) ) {
@@ -306,7 +306,7 @@
                        'first_name' => 'fname',
                        'gross' => 'amount',
                        'last_name' => 'lname',
-                       'postal_code' => 'zip',
+                       'postal' => 'postal',
                        'state_province' => 'state',
                        'street_address' => 'street',
                        'supplemental_address_1' => 'street_supplemental',
diff --git a/gateway_common/donation.api.php b/gateway_common/donation.api.php
index 4a77272..07421c4 100644
--- a/gateway_common/donation.api.php
+++ b/gateway_common/donation.api.php
@@ -102,7 +102,7 @@
                        'street_supplemental' => $this->defineParam( false ),
                        'city' => $this->defineParam( false ),
                        'state' => $this->defineParam( false ),
-                       'zip' => $this->defineParam( false ),
+                       'postal' => $this->defineParam( false ),
                        'email' => $this->defineParam( false ),
                        'country' => $this->defineParam( false ),
                        'card_num' => $this->defineParam( false ),
diff --git a/gateway_common/gateway.adapter.php 
b/gateway_common/gateway.adapter.php
index 624684f..8304f4c 100644
--- a/gateway_common/gateway.adapter.php
+++ b/gateway_common/gateway.adapter.php
@@ -2428,7 +2428,7 @@
                                                'street',
                                                'city',
                                                'country',
-                                               'zip', //this should really be 
added or removed, depending on the country and/or gateway requirements.
+                                               'postal', //this should really 
be added or removed, depending on the country and/or gateway requirements.
                                                //however, that's not happening 
in this class in the code I'm replacing, so...
                                                //TODO: Something clever in the 
DataValidator with data groups like these.
                                        );
diff --git a/gateway_forms/Mustache.php b/gateway_forms/Mustache.php
index e62071e..6a481d4 100644
--- a/gateway_forms/Mustache.php
+++ b/gateway_forms/Mustache.php
@@ -171,7 +171,7 @@
                $address_fields = array(
                        'city',
                        'state',
-                       'zip',
+                       'postal',
                        'street',
                );
                $address_field_count = 0;
diff --git a/gateway_forms/mustache/personal_info.html.mustache 
b/gateway_forms/mustache/personal_info.html.mustache
index 12da095..c5f4f95 100644
--- a/gateway_forms/mustache/personal_info.html.mustache
+++ b/gateway_forms/mustache/personal_info.html.mustache
@@ -22,9 +22,9 @@
                                                                <input 
class="{{ address_css_class }}" name="city" value="{{ city }}" type="text" 
placeholder="{{ l10n "donate_interface-donor-city" }}" id="city" required 
autocomplete="billing address-level2">
 {{/ city_required }}
 {{> state_dropdown }}{{! only renders if required }}
-{{# zip_required }}
-                                                               <input 
class="{{ address_css_class }}" name="zip" value="{{ zip }}" type="text" 
placeholder="{{ l10n "donate_interface-donor-postal" }}" id="zip" required 
autocomplete="billing postal-code">
-{{/ zip_required }}
+{{# postal_required }}
+                                                               <input 
class="{{ address_css_class }}" name="postal" value="{{ postal }}" type="text" 
placeholder="{{ l10n "donate_interface-donor-postal" }}" id="postal" required 
autocomplete="billing postal-code">
+{{/ postal_required }}
                                                        </td>
                                                </tr>
 
@@ -34,9 +34,9 @@
     {{# state_required }}
                         {{{ fieldError "state" }}}
     {{/ state_required }}
-    {{# zip_required }}
-                        {{{ fieldError "postal_code" }}}
-    {{/ zip_required }}
+    {{# postal_required }}
+                        {{{ fieldError "postal" }}}
+    {{/ postal_required }}
 {{/ address_required }}
 {{# fiscal_number_required }}
                                                <tr>
diff --git a/globalcollect_gateway/config/data_constraints.yaml 
b/globalcollect_gateway/config/data_constraints.yaml
index 8af0555..09f18e5 100644
--- a/globalcollect_gateway/config/data_constraints.yaml
+++ b/globalcollect_gateway/config/data_constraints.yaml
@@ -202,7 +202,7 @@
     type: alphanumeric
     length: 2
 # ZIP: AN10
-zip:
+postal:
     type: alphanumeric
     length: 10
 
diff --git a/globalcollect_gateway/config/var_map.yaml 
b/globalcollect_gateway/config/var_map.yaml
index 37b0b8f..c774035 100644
--- a/globalcollect_gateway/config/var_map.yaml
+++ b/globalcollect_gateway/config/var_map.yaml
@@ -54,5 +54,5 @@
 SURNAME: lname
 SWIFTCODE: swift_code
 TRANSACTIONTYPE: transaction_type # dd:GB,NL
-ZIP: zip
+ZIP: postal
 FISCALNUMBER: fiscal_number # Boletos
diff --git a/modules/js/ext.donationInterface.forms.js 
b/modules/js/ext.donationInterface.forms.js
index a777555..1f04649 100644
--- a/modules/js/ext.donationInterface.forms.js
+++ b/modules/js/ext.donationInterface.forms.js
@@ -48,7 +48,7 @@
                        street: $( '#street' ).val(),
                        city: $( '#city' ).val(),
                        state: $( '#state' ).val(),
-                       zip: $( '#zip' ).val(),
+                       postal: $( '#postal' ).val(),
                        email: $( '#email' ).val(),
                        country: $( '#country' ).val(),
                        payment_method: $( '#payment_method' ).val(),
diff --git a/tests/phpunit/Adapter/Adyen/AdyenTest.php 
b/tests/phpunit/Adapter/Adyen/AdyenTest.php
index 888339f..47cf138 100644
--- a/tests/phpunit/Adapter/Adyen/AdyenTest.php
+++ b/tests/phpunit/Adapter/Adyen/AdyenTest.php
@@ -56,7 +56,7 @@
                        'allowedMethods' => 'card',
                        'billingAddress.street' => $init['street'],
                        'billingAddress.city' => $init['city'],
-                       'billingAddress.postalCode' => $init['zip'],
+                       'billingAddress.postalCode' => $init['postal'],
                        'billingAddress.stateOrProvince' => $init['state'],
                        'billingAddress.country' => $init['country'],
                        'billingAddress.houseNumberOrName' => 'NA',
@@ -118,7 +118,7 @@
                        'allowedMethods' => 'card',
                        'billingAddress.street' => $init['street'],
                        'billingAddress.city' => $init['city'],
-                       'billingAddress.postalCode' => $init['zip'],
+                       'billingAddress.postalCode' => $init['postal'],
                        'billingAddress.stateOrProvince' => $init['state'],
                        'billingAddress.country' => $init['country'],
                        'billingAddress.houseNumberOrName' => 'NA',
diff --git a/tests/phpunit/Adapter/GatewayAdapterTest.php 
b/tests/phpunit/Adapter/GatewayAdapterTest.php
index b1b9231..4382c6e 100644
--- a/tests/phpunit/Adapter/GatewayAdapterTest.php
+++ b/tests/phpunit/Adapter/GatewayAdapterTest.php
@@ -228,9 +228,9 @@
                        'Street must be stuffed with fake data to prevent AVS 
scam.' );
        }
 
-       public function testZipStaging() {
+       public function testPostalCodeStaging() {
                $options = $this->getDonorTestData( 'BR' );
-               unset( $options['zip'] );
+               unset( $options['postal'] );
                $options['payment_method'] = 'cc';
                $options['payment_submethod'] = 'visa';
                $this->setUpRequest( $options );
@@ -239,7 +239,7 @@
                $exposed = TestingAccessWrapper::newFromObject( $gateway );
                $exposed->stageData();
 
-               $this->assertEquals( '0', $exposed->getData_Staged( 'zip' ),
+               $this->assertEquals( '0', $exposed->getData_Staged( 'postal' ),
                        'Postal code must be stuffed with fake data to prevent 
AVS scam.' );
        }
 
diff --git a/tests/phpunit/Adapter/GlobalCollect/GlobalCollectFormLoadTest.php 
b/tests/phpunit/Adapter/GlobalCollect/GlobalCollectFormLoadTest.php
index b178b6d..7ab0e62 100644
--- a/tests/phpunit/Adapter/GlobalCollect/GlobalCollectFormLoadTest.php
+++ b/tests/phpunit/Adapter/GlobalCollect/GlobalCollectFormLoadTest.php
@@ -256,9 +256,9 @@
                                'nodename' => 'select',
                                'selected' => 'SK',
                        ),
-                       'zip' => array (
+                       'postal' => array (
                                'nodename' => 'input',
-                               'value' => $init['zip'],
+                               'value' => $init['postal'],
                        ),
                        'country' => array (
                                'nodename' => 'input',
diff --git a/tests/phpunit/Adapter/GlobalCollect/GlobalCollectTest.php 
b/tests/phpunit/Adapter/GlobalCollect/GlobalCollectTest.php
index 482bb9d..31df336 100644
--- a/tests/phpunit/Adapter/GlobalCollect/GlobalCollectTest.php
+++ b/tests/phpunit/Adapter/GlobalCollect/GlobalCollectTest.php
@@ -305,7 +305,7 @@
                        'STREET' => 'street',
                        'CITY' => 'city',
                        'STATE' => 'state',
-                       'ZIP' => 'zip',
+                       'ZIP' => 'postal',
                        'EMAIL' => 'email',
                        'ACCOUNTHOLDER' => 'account_holder',
                        'ACCOUNTNAME' => 'account_name',
@@ -488,7 +488,7 @@
                        'utm_campaign'=>'C14_en5C_dec_dsk_FR',
                        'utm_medium'=>'sitenotice',
                        'utm_source'=>'B14_120921_5C_lg_fnt_sans.no-LP.cc',
-                       'zip'=>'90210'
+                       'postal'=>'90210'
                ) );
 
                $gateway = new TestingGlobalCollectAdapter( array( 
'api_request' => 'true' ) );
diff --git a/tests/phpunit/DonationDataTest.php 
b/tests/phpunit/DonationDataTest.php
index 6649ba1..221e44c 100644
--- a/tests/phpunit/DonationDataTest.php
+++ b/tests/phpunit/DonationDataTest.php
@@ -47,7 +47,7 @@
                        'street' => '123 Fake Street',
                        'city' => 'Springfield',
                        'state' => 'US',
-                       'zip' => '99999',
+                       'postal' => '99999',
                        'country' => 'US',
                        'card_num' => '42',
                        'card_type' => 'visa',
@@ -123,7 +123,7 @@
                        'street' => '548 Market St.',
                        'city' => 'San Francisco',
                        'state' => 'CA',
-                       'zip' => '94104',
+                       'postal' => '94104',
                        'country' => 'US',
                        'card_num' => '378282246310005',
                        'card_type' => 'amex',
@@ -179,7 +179,7 @@
                        'street' => '548 Market St.',
                        'city' => 'San Francisco',
                        'state' => 'CA',
-                       'zip' => '94104',
+                       'postal' => '94104',
                        'country' => 'US',
                        'card_num' => '378282246310005',
                        'card_type' => 'amex',
@@ -275,10 +275,10 @@
         */
        public function testIsSomething(){
                $data = $this->testData;
-               unset( $data['zip'] );
+               unset( $data['postal'] );
 
                $ddObj = new DonationData( $this->getFreshGatewayObject( 
self::$initial_vars ), $data ); //change to test mode with explicit test data
-               $this->assertEquals($ddObj->isSomething('zip'), false, "Zip 
should currently be nothing.");
+               $this->assertEquals($ddObj->isSomething('postal'), false, "Zip 
should currently be nothing.");
                $this->assertEquals($ddObj->isSomething('lname'), true, "Lname 
should currently be something.");
        }
 
diff --git a/tests/phpunit/DonationInterfaceTestCase.php 
b/tests/phpunit/DonationInterfaceTestCase.php
index 1d26801..80d86ae 100644
--- a/tests/phpunit/DonationInterfaceTestCase.php
+++ b/tests/phpunit/DonationInterfaceTestCase.php
@@ -146,7 +146,7 @@
                        'US' => array ( //default
                                'city' => 'San Francisco',
                                'state' => 'CA',
-                               'zip' => '94105',
+                               'postal' => '94105',
                                'currency_code' => 'USD',
                                'street' => '123 Fake Street',
                                'fname' => 'Firstname',
@@ -158,7 +158,7 @@
                        'ES' => array (
                                'city' => 'Barcelona',
                                'state' => 'XX',
-                               'zip' => '0',
+                               'postal' => '0',
                                'currency_code' => 'EUR',
                                'street' => '123 Calle Fake',
                                'fname' => 'Nombre',
@@ -169,7 +169,7 @@
                        'Catalonia' => array (
                                'city' => 'Barcelona',
                                'state' => 'XX',
-                               'zip' => '0',
+                               'postal' => '0',
                                'currency_code' => 'EUR',
                                'street' => '123 Calle Fake',
                                'fname' => 'Nombre',
@@ -180,7 +180,7 @@
                        'NO' => array (
                                'city' => 'Oslo',
                                'state' => 'XX',
-                               'zip' => '0',
+                               'postal' => '0',
                                'currency_code' => 'EUR',
                                'street' => '123 Fake Gate',
                                'fname' => 'Fornavn',
@@ -191,7 +191,7 @@
                        'FR' => array (
                                'city' => 'Versailles',
                                'state' => 'XX',
-                               'zip' => '0',
+                               'postal' => '0',
                                'currency_code' => 'EUR',
                                'street' => '123 Rue Faux',
                                'fname' => 'Prénom',
@@ -203,7 +203,7 @@
                        'FJ' => array (
                                'city' => 'Suva',
                                'state' => 'XX',
-                               'zip' => '0',
+                               'postal' => '0',
                                'currency_code' => 'EUR',
                                'street' => '123 Fake Street',
                                'fname' => 'FirstName',
@@ -214,7 +214,7 @@
                        'NL' => array (
                                'city' => 'Amsterdam',
                                'state' => 'XX',
-                               'zip' => '0',
+                               'postal' => '0',
                                'currency_code' => 'EUR',
                                'street' => '123 nep straat',
                                'fname' => 'Voornaam',
@@ -225,7 +225,7 @@
                        'BE' => array (
                                'city' => 'Antwerp',
                                'state' => 'XX',
-                               'zip' => '0',
+                               'postal' => '0',
                                'currency_code' => 'EUR',
                                'street' => '123 nep straat',
                                'fname' => 'Voornaam',
@@ -236,7 +236,7 @@
                        'IT' => array (
                                'city' => 'Torino',
                                'state' => 'TO',
-                               'zip' => '10123',
+                               'postal' => '10123',
                                'currency_code' => 'EUR',
                                'street' => 'Via Falso 123',
                                'fname' => 'Nome',
@@ -247,7 +247,7 @@
                        'CA' => array (
                                'city' => 'Saskatoon',
                                'state' => 'SK',
-                               'zip' => 'S7K 0J5',
+                               'postal' => 'S7K 0J5',
                                'currency_code' => 'CAD',
                                'street' => '123 Fake Street',
                                'fname' => 'Firstname',
@@ -387,7 +387,7 @@
                $expected .=                            '<STREET>' . 
$options['street'] . '</STREET>';
                $expected .=                            '<CITY>' . 
$options['city'] . '</CITY>';
                $expected .=                            '<STATE>' . 
$options['state'] . '</STATE>';
-               $expected .=                            '<ZIP>' . 
$options['zip'] . '</ZIP>';
+               $expected .=                            '<ZIP>' . 
$options['postal'] . '</ZIP>';
                $expected .= '<EMAIL>' . TESTS_EMAIL . '</EMAIL>';
 
                // Set the issuer id if it is passed.
diff --git a/tests/phpunit/DonationQueueTest.php 
b/tests/phpunit/DonationQueueTest.php
index 4ddb350..48ca11b 100644
--- a/tests/phpunit/DonationQueueTest.php
+++ b/tests/phpunit/DonationQueueTest.php
@@ -68,7 +68,7 @@
                        'street' => '1 Fake St.',
                        'user_ip' => '127.0.0.1',
                        'utm_source' => 'testing',
-                       'zip' => '12345',
+                       'postal' => '12345',
                );
 
                $this->expected_message = array(
@@ -82,7 +82,7 @@
                        'city' => 'Dunburger',
                        'state_province' => 'AK',
                        'country' => 'US',
-                       'postal_code' => '12345',
+                       'postal' => '12345',
                        'gateway' => 'testgateway',
                        'gateway_account' => 'default',
                        'gateway_txn_id' => 
$this->transaction['gateway_txn_id'],
diff --git a/tests/phpunit/GatewayPageTest.php 
b/tests/phpunit/GatewayPageTest.php
index de7e330..6289f95 100644
--- a/tests/phpunit/GatewayPageTest.php
+++ b/tests/phpunit/GatewayPageTest.php
@@ -194,7 +194,7 @@
                        'street' => '123 Fake Street',
                        'city' => 'San Francisco',
                        'state' => 'CA',
-                       'zip' => '94105',
+                       'postal' => '94105',
                        'php-message-class' => 
'SmashPig\CrmLink\Messages\DonationInterfaceMessage',
                );
                $actual = json_decode( $detailString, true );
diff --git a/tests/phpunit/LoggingTest.php b/tests/phpunit/LoggingTest.php
index 1aba78b..2f66926 100644
--- a/tests/phpunit/LoggingTest.php
+++ b/tests/phpunit/LoggingTest.php
@@ -70,7 +70,7 @@
                        'street' => '123 Fake Street',
                        'user_ip' => '127.0.0.1',
                        'utm_source' => '..cc',
-                       'zip' => '94105',
+                       'postal' => '94105',
                        'response' => 'Original Response Status 
(pre-SET_PAYMENT): 200',
                        'php-message-class' => 
'SmashPig\CrmLink\Messages\DonationInterfaceMessage',
                        'gateway_account' => 'test',
@@ -123,7 +123,7 @@
                        'street' => '123 Fake Street',
                        'user_ip' => '127.0.0.1',
                        'utm_source' => '..cc',
-                       'zip' => '94105',
+                       'postal' => '94105',
                        'response' => 'Original Response Status 
(pre-SET_PAYMENT): 200',
                        'php-message-class' => 
'SmashPig\CrmLink\Messages\DonationInterfaceMessage',
                        'gateway_account' => 'test',

diff --git a/gateway_common/StreetAddress.php b/gateway_common/StreetAddress.php
index 39a00cc..2ed4055 100644
--- a/gateway_common/StreetAddress.php
+++ b/gateway_common/StreetAddress.php
@@ -3,7 +3,7 @@
 class StreetAddress implements StagingHelper {
        public function stage( GatewayType $adapter, $normalized, &$stagedData 
) {
                $stagedData['street'] = $this->stage_street( $normalized );
-               $stagedData['zip'] = $this->stage_zip( $normalized );
+               $stagedData['postal'] = $this->stage_postal( $normalized );
        }
 
        /**
@@ -35,34 +35,34 @@
         * In the event that there isn't anything in there, we need to send
         * something along so that AVS checks get triggered at all.
         */
-       protected function stage_zip( $normalized ) {
-               $zip = '';
-               if ( isset( $normalized['zip'] ) ) {
-                       $zip = trim( $normalized['zip'] );
+       protected function stage_postal( $normalized ) {
+               $postal = '';
+               if ( isset( $normalized['postal'] ) ) {
+                       $postal = trim( $normalized['postal'] );
                }
-               if ( strlen( $zip ) === 0 ) {
+               if ( strlen( $postal ) === 0 ) {
                        //it would be nice to check for more here, but the 
world has some
                        //straaaange postal codes...
-                       $zip = '0';
+                       $postal = '0';
                }
 
                //country-based zip grooming to make AVS (marginally) happy
happy
                if ( !empty( $normalized['country'] ) ) {
                        switch ( $normalized['country'] ) {
                        case 'CA':
                                //Canada goes "A0A 0A0"
-                               $this->staged_data['zip'] = strtoupper( $zip );
+                               $this->staged_data['postal'] = strtoupper( 
$postal );
                                //In the event that they only forgot the space, 
help 'em out.
                                $regex = '/[A-Z]\d[A-Z]\d[A-Z]\d/';
-                               if ( strlen( $this->staged_data['zip'] ) === 6
-                                       && preg_match( $regex, $zip )
+                               if ( strlen( $this->staged_data['postal'] ) === 
6
+                                       && preg_match( $regex, $postal )
                                ) {
-                                       $zip = substr( $zip, 0, 3 ) . ' ' . 
substr( $zip, 3, 3 );
+                                       $postal = substr( $postal, 0, 3 ) . ' ' 
. substr( $postal, 3, 3 );
                                }
                                break;
                        }
                }
 
-               return $zip;
+               return $postal;
        }
 }
@@ -35,34 +35,34 @@
                }
 
-               //country-based zip grooming to make AVS (marginally) happy
+               //country-based postal code grooming to make AVS (marginally) 
happy
                if ( !empty( $normalized['country'] ) ) {
-- 
To view, visit https://gerrit.wikimedia.org/r/320267
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I7a60dccae692631a32381a69eef2dd1c6ba9e32e
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/DonationInterface
Gerrit-Branch: master
Gerrit-Owner: Ejegg <eeggles...@wikimedia.org>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to